<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Foundation.Interop

Windows Runtime (WinRT) APIs for for the `Windows.Foundation.Interop` namespace.

This package provides the `winrt.windows.foundation.interop` module.
